@@ -43,7 +43,7 @@ private inline fun <U, E: Exception> rustCallWithError(errorHandler: CallStatusE
         // with the message.  but if that code panics, then it just sends back
         // an empty buffer.
         if (status.error_buf.len > 0) {
-            throw InternalException({{ "status.error_buf"|lift_kt(Type::String) }})
+            throw InternalException({{ "status.error_buf"|lift_var(Type::String) }})
         } else {
             throw InternalException("Rust panic")
         }
@@ -63,4 +63,4 @@ object NullCallStatusErrorHandler: CallStatusErrorHandler<InternalException> {
 // Call a rust function that returns a plain value
 private inline fun <U> rustCall(callback: (RustCallStatus) -> U): U {
     return rustCallWithError(NullCallStatusErrorHandler, callback);
-}
\ No newline at end of file
+}
