@@ -1,3 +1,5 @@
+{% import "macros.py" as py %}
+{%- let func = self.inner() %}
 {%- match func.return_type() -%}
 {%- when Some with (return_type) %}
 
@@ -11,4 +13,4 @@ def {{ func.name()|fn_name_py }}({%- call py::arg_list_decl(func) -%}):
 def {{ func.name()|fn_name_py }}({%- call py::arg_list_decl(func) -%}):
     {%- call py::coerce_args(func) %}
     {% call py::to_ffi_call(func) %}
-{% endmatch %}
\ No newline at end of file
+{% endmatch %}
